@@ -1,15 +1,12 @@
 package Lout ; # Documented at the __END__.
 
-# $Id: Lout.pm,v 1.7 1999/07/18 11:20:26 root Exp $
-
-# Copyright (c) 1999 Mark Summerfield. All Rights Reserved.
-# May be used/distributed under the same terms as Perl itself.
+# $Id: Lout.pm,v 1.11 1999/08/08 15:16:58 root Exp $
 
 
 use strict ; 
 
-use vars qw( $VERSION ) ;
-$VERSION    = '1.00' ;
+use vars qw( $VERSION %Entity2char ) ;
+$VERSION    = '1.03' ;
 
 
 my %option = (
@@ -22,7 +19,7 @@ my %option = (
 # This hash (and most of its comments) is copied from Gisle Aas
 # HTML::Entities.pm module with the plain text characters being replaced by
 # their Lout equivalents.
-my %Entity2char = (
+%Entity2char = (
     # Some normal chars that have special meaning in SGML context
     amp     => '&',     # Note we convert & to "&" later. # ampersand 
     'gt'    => '>',     # greater than
@@ -219,7 +216,7 @@ sub txt2lout {
         s/$PARA/\n/go ;
     }
     else {
-        s/$PARA/\n\@LP\n/go ;
+        s/$PARA/\n\@PP\n/go ;
     }
     s/$AT/"@"/go ;
     s/$LBRACE/{/go ;
@@ -334,17 +331,21 @@ None that I know of!
 
 1999/07/18  First properly documented release. 
 
+1999/07/28  Put %Entity2char in the symbol table so that other perl programs
+            can access it, for example lout2html.
+
+1999/08/08  Changed licence to LGPL.
+
 =head1 AUTHOR
 
-Mark Summerfield. I can be contacted as <mark.summerfield@chest.ac.uk> -
+Mark Summerfield. I can be contacted as <summer@chest.ac.uk> -
 please include the word 'lout' in the subject line.
 
 =head1 COPYRIGHT
 
 Copyright (c) Mark Summerfield 1999. All Rights Reserved.
 
-This module may be used/distributed/modified under the same terms as Perl
-itself.
+This module may be used/distributed/modified under the LGPL. 
 
 =cut
 
